#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-explicit-imports-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-explicit-imports-plugin-2.3.0.0-3Owms0PSf58GstGC62fysW
key:                  hls-explicit-imports-plugin-2.3.0.0-3Owms0PSf58GstGC62fysW
license:              Apache-2.0
maintainer:           pepeiborra@gmail.com
author:               Pepe Iborra
synopsis:             Explicit imports plugin for Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  a35a4f733b4636123cd4e793b5005d50
exposed:              True
exposed-modules:      Ide.Plugin.ExplicitImports
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.3.0.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.3.0.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hls-explicit-imports-plugin-2.3.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-explicit-imports-plugin
hs-libraries:
    HShls-explicit-imports-plugin-2.3.0.0-3Owms0PSf58GstGC62fysW

depends:
    aeson-2.2.1.0-2aoKFKPwHseOu8oBERSIn base-4.18.2.1 containers-0.6.7
    deepseq-1.4.8.1 ghc-9.6.6 ghcide-2.3.0.0-4WfDNWdvbs978HGuOEpRo5
    hls-graph-2.3.0.0-Dwp4mrhjHCyGH7wYWnrCby
    hls-plugin-api-2.3.0.0-21dgaLnGjvU4x9vzlj6c31
    lens-5.3.4-95zsvsVvew2LnSS9OomrvK
    lsp-2.2.0.0-FKv2O1GO4Nd9OczNPSMEVw mtl-2.3.1 text-2.0.2
    transformers-0.6.1.0
    unordered-containers-0.2.20.1-1lWFLFb7qnGGdfGyTf5Bys

haddock-interfaces:
    /usr/share/doc/haskell-hls-explicit-imports-plugin/html/hls-explicit-imports-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-explicit-imports-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

